NamingUtils class

Constructors

NamingUtils(String rawFeature, String usecaseAction)

Properties

actionCamel String
latefinal
actionLower String
latefinal
actionPascal String
latefinal
featureCap String
latefinal
featureLower String
latefinal
fieldName String
latefinal
hashCode int
The hash code for this object.
no setterinherited
rawFeature String
final
requestClass String
latefinal
responseClass String
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usecaseAction String
final
usecaseClass String
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited